/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// syntax table for Singular
//
// - search for an exact match of the argument types
// - otherwise search for the first possibility
//   with converted types of the arguments
// - otherwise report an error
//
// operation: ++ (identifier)  ->  nothing
// operation: -- (identifier)  ->  nothing
// operation: - (int)  ->  int
// operation: - (bigint)  ->  bigint
// operation: - (number)  ->  number
// operation: - (poly)  ->  poly
// operation: - (vector)  ->  vector
// operation: - (matrix)  ->  matrix
// operation: - (intvec)  ->  intvec
// operation: - (intmat)  ->  intmat
// operation: ( (proc)  ->  any_type
// operation: attrib (def)  ->  nothing
// operation: bareiss (module)  ->  list
// operation: betti (list)  ->  intmat
// operation: betti (resolution)  ->  intmat
// operation: betti (ideal)  ->  intmat
// operation: betti (module)  ->  intmat
// operation: bigint (bigint)  ->  bigint
// operation: bigint (number)  ->  bigint
// operation: bigint (poly)  ->  bigint
// operation: char (ring)  ->  int
// operation: char (qring)  ->  int
// operation: char_series (ideal)  ->  matrix
// operation: charstr (ring)  ->  string
// operation: charstr (qring)  ->  string
// operation: close (link)  ->  nothing
// operation: ncols (matrix)  ->  int
// operation: ncols (ideal)  ->  int
// operation: ncols (module)  ->  int
// operation: ncols (intmat)  ->  int
// DUMMY // operation: ncols (intvec)  ->  $INVALID$
// operation: cleardenom (poly)  ->  poly
// operation: cleardenom (vector)  ->  vector
// operation: size (bigint)  ->  int
// operation: size (number)  ->  int
// operation: size (resolution)  ->  int
// operation: size (string)  ->  int
// operation: size (poly)  ->  int
// operation: size (vector)  ->  int
// operation: size (ideal)  ->  int
// operation: size (module)  ->  int
// operation: size (matrix)  ->  int
// operation: size (intvec)  ->  int
// operation: size (intmat)  ->  int
// operation: size (list)  ->  int
// operation: size (ring)  ->  int
// operation: def (int)  ->  def
// DUMMY // operation: def (any_type)  ->  $INVALID$
// operation: deg (poly)  ->  int
// operation: deg (vector)  ->  int
// operation: deg (matrix)  ->  int
// operation: degree (ideal)  ->  string
// operation: degree (module)  ->  string
// operation: defined (def)  ->  int
// operation: det (intmat)  ->  int
// operation: det (matrix)  ->  poly
// operation: det (module)  ->  poly
// operation: dim (ideal)  ->  int
// operation: dim (module)  ->  int
// operation: dim (resolution)  ->  int
// operation: dump (link)  ->  nothing
// operation: gen (int)  ->  vector
// operation: execute (string)  ->  nothing
// operation: ERROR (string)  ->  nothing
// operation: factorize (poly)  ->  list
// operation: finduni (ideal)  ->  ideal
// operation: freemodule (int)  ->  module
// operation: facstd (ideal)  ->  list
// operation: getdump (link)  ->  nothing
// operation: highcorner (ideal)  ->  poly
// operation: highcorner (module)  ->  vector
// operation: hilb (ideal)  ->  nothing
// operation: hilb (module)  ->  nothing
// operation: hilb (intvec)  ->  intvec
// operation: homog (ideal)  ->  int
// operation: homog (module)  ->  int
// operation: ideal (ideal)  ->  ideal
// operation: ideal (vector)  ->  ideal
// operation: ideal (matrix)  ->  ideal
// operation: ideal (qring)  ->  ideal
// operation: ideal (ring)  ->  ideal
// operation: ideal (map)  ->  ideal
// operation: impart (number)  ->  number
// operation: indepSet (ideal)  ->  intvec
// operation: int (int)  ->  int
// operation: int (bigint)  ->  int
// operation: int (number)  ->  int
// operation: int (poly)  ->  int
// operation: interred (ideal)  ->  ideal
// operation: interred (module)  ->  module
// operation: intmat (intmat)  ->  intmat
// operation: intvec (intmat)  ->  intvec
// operation: intvec (intvec)  ->  intvec
// operation: rvar (poly)  ->  int
// operation: rvar (string)  ->  int
// operation: rvar (any_type)  ->  int
// operation: jacob (poly)  ->  ideal
// operation: jacob (ideal)  ->  matrix
// operation: jacob (module)  ->  module
// operation: janet (ideal)  ->  ideal
// operation: kbase (ideal)  ->  ideal
// operation: kbase (module)  ->  module
// operation: ludecomp (matrix)  ->  list
// operation: primefactors (bigint)  ->  list
// operation: primefactors (number)  ->  list
// operation: killattrib (identifier)  ->  nothing
// operation: lead (poly)  ->  poly
// operation: lead (ideal)  ->  ideal
// operation: lead (vector)  ->  vector
// operation: lead (module)  ->  module
// operation: leadcoef (poly)  ->  number
// operation: leadcoef (vector)  ->  number
// operation: leadexp (poly)  ->  intvec
// operation: leadexp (vector)  ->  intvec
// operation: leadmonom (poly)  ->  poly
// operation: leadmonom (vector)  ->  vector
// operation: link (link)  ->  link
// operation: list (def)  ->  list
// DUMMY // operation: map (any_type)  ->  $INVALID$
// operation: matrix (matrix)  ->  matrix
// operation: maxideal (int)  ->  ideal
// operation: memory (int)  ->  bigint
// operation: minbase (ideal)  ->  ideal
// operation: minbase (module)  ->  module
// operation: minres (list)  ->  list
// operation: minres (resolution)  ->  resolution
// operation: module (module)  ->  module
// operation: monitor (link)  ->  nothing
// operation: monomial (intvec)  ->  poly
// operation: mult (ideal)  ->  int
// operation: mult (module)  ->  int
// operation: mstd (ideal)  ->  list
// operation: mstd (module)  ->  list
// operation: nameof (any_type)  ->  string
// operation: names (package)  ->  list
// operation: names (ring)  ->  list
// operation: names (qring)  ->  list
// operation: number (number)  ->  number
// operation: number (poly)  ->  number
// operation: number (bigint)  ->  number
// operation: npars (ring)  ->  int
// operation: npars (qring)  ->  int
// operation: nvars (ring)  ->  int
// operation: nvars (qring)  ->  int
// operation: open (link)  ->  nothing
// operation: ord (poly)  ->  int
// operation: ord (vector)  ->  int
// operation: ordstr (ring)  ->  string
// operation: ordstr (qring)  ->  string
// operation: par (int)  ->  number
// operation: pardeg (number)  ->  int
// operation: parstr (int)  ->  string
// operation: parstr (ring)  ->  string
// operation: parstr (qring)  ->  string
// operation: poly (poly)  ->  poly
// operation: poly (bigint)  ->  poly
// operation: preimage (map)  ->  ring
// operation: prime (int)  ->  int
// operation: print (list)  ->  string
// operation: print (def)  ->  string
// operation: proc (proc)  ->  proc
// operation: prune (module)  ->  module
// operation: qhweight (ideal)  ->  intvec
// operation: qhweight (module)  ->  intvec
// DUMMY // operation: qring (any_type)  ->  $INVALID$
// operation: rank (matrix)  ->  int
// operation: read (link)  ->  string
// operation: regularity (list)  ->  int
// operation: repart (number)  ->  number
// operation: reservedName (string)  ->  int
// operation: resolution (list)  ->  resolution
// operation: resolution (resolution)  ->  resolution
// operation: ringlist (ring)  ->  list
// operation: ringlist (qring)  ->  list
// operation: ring (ring)  ->  ring
// operation: ring (list)  ->  ring
// operation: nrows (vector)  ->  int
// operation: nrows (module)  ->  int
// operation: nrows (matrix)  ->  int
// operation: nrows (intmat)  ->  int
// operation: nrows (intvec)  ->  int
// operation: slimgb (ideal)  ->  ideal
// operation: slimgb (module)  ->  module
// operation: sortvec (ideal)  ->  intvec
// operation: sortvec (module)  ->  intvec
// operation: sqrfree (poly)  ->  ideal
// operation: std (ideal)  ->  ideal
// operation: std (module)  ->  module
// operation: string (string)  ->  string
// operation: system (string)  ->  nothing
// operation: syz (ideal)  ->  module
// operation: syz (module)  ->  module
// operation: envelope (ring)  ->  ring
// operation: envelope (qring)  ->  qring
// operation: opposite (ring)  ->  ring
// operation: opposite (qring)  ->  qring
// operation: twostd (ideal)  ->  ideal
// DUMMY // operation: trace (intvec)  ->  $INVALID$
// DUMMY // operation: trace (ideal)  ->  $INVALID$
// operation: trace (intmat)  ->  int
// operation: trace (matrix)  ->  poly
// operation: transpose (intvec)  ->  intmat
// operation: transpose (intmat)  ->  intmat
// operation: transpose (matrix)  ->  matrix
// operation: transpose (module)  ->  module
// operation: typeof (any_type)  ->  string
// operation: univariate (poly)  ->  int
// operation: variables (poly)  ->  ideal
// operation: variables (ideal)  ->  ideal
// operation: variables (matrix)  ->  ideal
// operation: vector (vector)  ->  vector
// operation: vdim (ideal)  ->  int
// operation: vdim (module)  ->  int
// operation: var (int)  ->  poly
// operation: varstr (int)  ->  string
// operation: varstr (ring)  ->  string
// operation: varstr (qring)  ->  string
// operation: weight (ideal)  ->  intvec
// operation: weight (module)  ->  intvec
// operation: load (string)  ->  nothing
// operation: convhull (ideal)  ->  ideal
// operation: waitfirst (list)  ->  int
// operation: waitall (list)  ->  int
/*---------------------------------------------*/
// operation: :: (def, def)  ->  any_type
// operation: + (int, int)  ->  int
// operation: + (bigint, bigint)  ->  bigint
// operation: + (number, number)  ->  number
// operation: + (poly, poly)  ->  poly
// operation: + (vector, vector)  ->  vector
// operation: + (ideal, ideal)  ->  ideal
// operation: + (module, module)  ->  module
// operation: + (poly, matrix)  ->  matrix
// operation: + (matrix, poly)  ->  matrix
// operation: + (matrix, matrix)  ->  matrix
// operation: + (string, string)  ->  string
// operation: + (intvec, int)  ->  intvec
// operation: + (int, intvec)  ->  intvec
// operation: + (intmat, int)  ->  intmat
// operation: + (int, intmat)  ->  intmat
// operation: + (intvec, intvec)  ->  intvec
// operation: + (intmat, intmat)  ->  intmat
// operation: + (list, list)  ->  list
// operation: + (ring, ring)  ->  ring
// operation: + (qring, ring)  ->  qring
// operation: + (ring, qring)  ->  qring
// operation: + (qring, qring)  ->  qring
// operation: - (int, int)  ->  int
// operation: - (bigint, bigint)  ->  bigint
// operation: - (number, number)  ->  number
// operation: - (poly, poly)  ->  poly
// operation: - (vector, vector)  ->  vector
// operation: - (matrix, poly)  ->  matrix
// operation: - (matrix, matrix)  ->  matrix
// operation: - (intvec, int)  ->  intvec
// operation: - (intmat, int)  ->  intmat
// operation: - (intvec, intvec)  ->  intvec
// operation: - (intmat, intmat)  ->  intmat
// DUMMY // operation: - (ideal, ideal)  ->  nothing
// DUMMY // operation: - (module, module)  ->  nothing
// operation: * (int, int)  ->  int
// operation: * (bigint, bigint)  ->  bigint
// operation: * (number, number)  ->  number
// operation: * (poly, poly)  ->  poly
// operation: * (poly, vector)  ->  vector
// operation: * (vector, poly)  ->  vector
// operation: * (ideal, poly)  ->  ideal
// operation: * (poly, ideal)  ->  ideal
// operation: * (module, poly)  ->  module
// operation: * (poly, module)  ->  module
// operation: * (ideal, ideal)  ->  ideal
// operation: * (ideal, vector)  ->  module
// operation: * (vector, ideal)  ->  module
// operation: * (ideal, module)  ->  module
// operation: * (module, ideal)  ->  module
// operation: * (matrix, poly)  ->  matrix
// operation: * (poly, matrix)  ->  matrix
// operation: * (matrix, number)  ->  matrix
// operation: * (number, matrix)  ->  matrix
// operation: * (matrix, int)  ->  matrix
// operation: * (int, matrix)  ->  matrix
// operation: * (matrix, matrix)  ->  matrix
// operation: * (matrix, bigint)  ->  matrix
// operation: * (bigint, matrix)  ->  matrix
// operation: * (intvec, int)  ->  intvec
// operation: * (int, intvec)  ->  intvec
// operation: * (intmat, int)  ->  intmat
// operation: * (int, intmat)  ->  intmat
// operation: * (intmat, intvec)  ->  intvec
// operation: * (intmat, intmat)  ->  intmat
// operation: * (intvec, intmat)  ->  intmat
// operation: / (number, number)  ->  number
// operation: / (poly, poly)  ->  poly
// operation: / (vector, poly)  ->  vector
// operation: / (matrix, poly)  ->  matrix
// operation: / (int, int)  ->  int
// operation: / (bigint, bigint)  ->  bigint
// operation: / (intvec, int)  ->  intvec
// operation: / (intmat, int)  ->  intmat
// operation: div (int, int)  ->  int
// operation: div (bigint, bigint)  ->  bigint
// operation: div (intvec, int)  ->  intvec
// operation: div (intmat, int)  ->  intmat
// operation: % (int, int)  ->  int
// operation: % (bigint, bigint)  ->  bigint
// operation: % (intvec, int)  ->  intvec
// operation: % (intmat, int)  ->  intmat
// operation: % (number, number)  ->  number
// operation: mod (int, int)  ->  int
// operation: mod (bigint, bigint)  ->  bigint
// operation: mod (intvec, int)  ->  intvec
// operation: mod (intmat, int)  ->  intmat
// operation: mod (number, number)  ->  number
// operation: ^ (int, int)  ->  int
// operation: ^ (bigint, int)  ->  bigint
// operation: ^ (number, int)  ->  number
// operation: ^ (poly, int)  ->  poly
// operation: ^ (ideal, int)  ->  ideal
// operation: <= (int, int)  ->  int
// operation: <= (bigint, bigint)  ->  int
// operation: <= (number, number)  ->  int
// operation: <= (string, string)  ->  int
// operation: <= (intvec, int)  ->  int
// operation: <= (intvec, intvec)  ->  int
// operation: <= (poly, poly)  ->  int
// operation: <= (vector, vector)  ->  int
// operation: < (int, int)  ->  int
// operation: < (bigint, bigint)  ->  int
// operation: < (number, number)  ->  int
// operation: < (intvec, int)  ->  int
// operation: < (intvec, intvec)  ->  int
// operation: < (string, string)  ->  int
// operation: < (poly, poly)  ->  int
// operation: < (vector, vector)  ->  int
// operation: >= (int, int)  ->  int
// operation: >= (bigint, bigint)  ->  int
// operation: >= (number, number)  ->  int
// operation: >= (string, string)  ->  int
// operation: >= (intvec, int)  ->  int
// operation: >= (intvec, intvec)  ->  int
// operation: >= (poly, poly)  ->  int
// operation: >= (vector, vector)  ->  int
// operation: > (int, int)  ->  int
// operation: > (bigint, bigint)  ->  int
// operation: > (number, number)  ->  int
// operation: > (string, string)  ->  int
// operation: > (intvec, int)  ->  int
// operation: > (intvec, intvec)  ->  int
// operation: > (poly, poly)  ->  int
// operation: > (vector, vector)  ->  int
// operation: and (int, int)  ->  int
// operation: or (int, int)  ->  int
// operation: == (int, int)  ->  int
// operation: == (bigint, bigint)  ->  int
// operation: == (number, number)  ->  int
// operation: == (string, string)  ->  int
// operation: == (poly, poly)  ->  int
// operation: == (vector, vector)  ->  int
// operation: == (intvec, int)  ->  int
// operation: == (intvec, intvec)  ->  int
// operation: == (intmat, intmat)  ->  int
// operation: == (matrix, matrix)  ->  int
// DUMMY // operation: == (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: == (module, module)  ->  $INVALID$
// DUMMY // operation: == (ideal, module)  ->  $INVALID$
// DUMMY // operation: == (module, ideal)  ->  $INVALID$
// operation: <> (int, int)  ->  int
// operation: <> (bigint, bigint)  ->  int
// operation: <> (number, number)  ->  int
// operation: <> (string, string)  ->  int
// operation: <> (poly, poly)  ->  int
// operation: <> (vector, vector)  ->  int
// operation: <> (intvec, intvec)  ->  int
// operation: <> (intmat, intmat)  ->  int
// operation: <> (matrix, matrix)  ->  int
// DUMMY // operation: <> (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: <> (module, module)  ->  $INVALID$
// DUMMY // operation: <> (ideal, module)  ->  $INVALID$
// DUMMY // operation: <> (module, ideal)  ->  $INVALID$
// operation: .. (int, int)  ->  intvec
// operation: [ (intvec, int)  ->  int
// operation: [ (intvec, intvec)  ->  int
// operation: [ (ideal, int)  ->  poly
// operation: [ (map, int)  ->  poly
// operation: [ (ideal, intvec)  ->  poly
// operation: [ (module, int)  ->  vector
// operation: [ (module, intvec)  ->  vector
// operation: [ (string, int)  ->  string
// operation: [ (string, intvec)  ->  string
// operation: [ (list, int)  ->  any_type
// operation: [ (list, intvec)  ->  any_type
// operation: [ (poly, int)  ->  poly
// operation: [ (poly, intvec)  ->  poly
// operation: [ (vector, int)  ->  poly
// operation: [ (vector, intvec)  ->  vector
// operation: ( (proc, def)  ->  any_type
// operation: ( (map, def)  ->  any_type
// operation: ( (LIB, string)  ->  nothing
// operation: ( (any_type, int)  ->  any_type
// operation: ( (any_type, intvec)  ->  any_type
// operation: : (int, int)  ->  intvec
// operation: attrib (def, string)  ->  nothing
// operation: betti (list, int)  ->  intmat
// operation: betti (resolution, int)  ->  intmat
// operation: betti (ideal, int)  ->  intmat
// operation: betti (module, int)  ->  intmat
// operation: bracket (poly, poly)  ->  poly
// operation: chinrem (intvec, intvec)  ->  bigint
// operation: chinrem (list, intvec)  ->  any_type
// operation: chinrem (list, list)  ->  any_type
// operation: coef (poly, poly)  ->  matrix
// operation: coeffs (ideal, poly)  ->  matrix
// operation: coeffs (module, poly)  ->  matrix
// operation: coeffs (ideal, ideal)  ->  matrix
// operation: coeffs (module, module)  ->  matrix
// operation: contract (ideal, ideal)  ->  matrix
// operation: deg (poly, intvec)  ->  int
// operation: deg (vector, intvec)  ->  int
// operation: deg (matrix, intvec)  ->  int
// operation: delete (list, int)  ->  list
// operation: diff (poly, poly)  ->  poly
// operation: diff (vector, poly)  ->  vector
// operation: diff (ideal, poly)  ->  ideal
// operation: diff (ideal, ideal)  ->  matrix
// operation: diff (module, poly)  ->  module
// operation: diff (matrix, poly)  ->  matrix
// operation: dim (ideal, ideal)  ->  int
// operation: dim (module, ideal)  ->  int
// operation: division (ideal, ideal)  ->  list
// operation: division (module, module)  ->  list
// operation: eliminate (ideal, poly)  ->  ideal
// operation: eliminate (module, poly)  ->  module
// operation: eliminate (ideal, intvec)  ->  ideal
// operation: eliminate (module, intvec)  ->  module
// operation: exportto (package, identifier)  ->  nothing
// operation: extgcd (int, int)  ->  list
// operation: extgcd (poly, poly)  ->  list
// operation: factorize (poly, int)  ->  ideal
// operation: facstd (ideal, ideal)  ->  list
// operation: farey (bigint, bigint)  ->  number
// operation: farey (ideal, bigint)  ->  any_type
// operation: farey (module, bigint)  ->  any_type
// operation: farey (matrix, bigint)  ->  any_type
// operation: fetch (ring, any_type)  ->  any_type
// operation: fetch (qring, any_type)  ->  any_type
// operation: fglm (ring, def)  ->  ideal
// operation: fglm (qring, def)  ->  ideal
// operation: fglmquot (ideal, poly)  ->  ideal
// operation: find (string, string)  ->  int
// operation: frwalk (ring, def)  ->  ideal
// operation: gcd (int, int)  ->  int
// operation: gcd (number, number)  ->  number
// operation: gcd (bigint, bigint)  ->  bigint
// operation: gcd (poly, poly)  ->  poly
// operation: hilb (ideal, int)  ->  intvec
// operation: hilb (module, int)  ->  intvec
// operation: homog (ideal, intvec)  ->  int
// operation: homog (module, intvec)  ->  int
// operation: homog (poly, poly)  ->  poly
// operation: homog (vector, poly)  ->  vector
// operation: homog (ideal, poly)  ->  ideal
// operation: homog (module, poly)  ->  module
// operation: hres (ideal, int)  ->  resolution
// operation: ideal (def, def)  ->  ideal
// operation: imap (ring, any_type)  ->  any_type
// operation: imap (qring, any_type)  ->  any_type
// operation: importfrom (package, any_type)  ->  nothing
// operation: indepSet (ideal, int)  ->  list
// operation: insert (list, def)  ->  list
// operation: interpolation (list, intvec)  ->  ideal
// operation: intersect (ideal, ideal)  ->  ideal
// operation: intersect (module, module)  ->  module
// operation: janet (ideal, int)  ->  ideal
// operation: jet (poly, int)  ->  poly
// operation: jet (ideal, int)  ->  ideal
// operation: jet (vector, int)  ->  vector
// operation: jet (module, int)  ->  module
// operation: jet (matrix, int)  ->  matrix
// operation: kbase (ideal, int)  ->  ideal
// operation: kbase (module, int)  ->  module
// operation: kernel (ring, any_type)  ->  ideal
// operation: kernel (qring, any_type)  ->  ideal
// operation: killattrib (identifier, string)  ->  nothing
// operation: koszul (int, int)  ->  matrix
// operation: koszul (int, ideal)  ->  matrix
// operation: kres (ideal, int)  ->  resolution
// operation: lift (ideal, ideal)  ->  matrix
// operation: lift (module, module)  ->  matrix
// operation: liftstd (ideal, matrix)  ->  ideal
// operation: liftstd (module, matrix)  ->  module
// operation: list (def, def)  ->  list
// operation: load (string, string)  ->  nothing
// operation: lres (ideal, int)  ->  resolution
// operation: module (def, def)  ->  module
// operation: modulo (ideal, ideal)  ->  module
// operation: modulo (module, module)  ->  module
// operation: monitor (link, string)  ->  nothing
// operation: mpresmat (ideal, int)  ->  module
// operation: newstruct (string, string)  ->  nothing
// operation: mres (ideal, int)  ->  resolution
// operation: mres (module, int)  ->  resolution
// operation: primefactors (bigint, bigint)  ->  list
// operation: primefactors (number, bigint)  ->  list
// operation: primefactors (bigint, number)  ->  list
// operation: primefactors (number, number)  ->  list
// operation: $INVALID$ (poly, poly)  ->  nothing
// operation: $INVALID$ (poly, matrix)  ->  nothing
// operation: $INVALID$ (matrix, poly)  ->  nothing
// operation: $INVALID$ (matrix, matrix)  ->  nothing
// operation: nc_algebra (poly, poly)  ->  ring
// operation: nc_algebra (poly, matrix)  ->  ring
// operation: nc_algebra (matrix, poly)  ->  ring
// operation: nc_algebra (matrix, matrix)  ->  ring
// operation: oppose (ring, def)  ->  any_type
// operation: oppose (qring, def)  ->  any_type
// operation: parstr (ring, int)  ->  string
// operation: parstr (qring, int)  ->  string
// operation: print (def, string)  ->  string
// operation: quotient (ideal, ideal)  ->  ideal
// operation: quotient (module, ideal)  ->  module
// operation: quotient (module, module)  ->  ideal
// operation: random (int, int)  ->  int
// operation: rank (matrix, int)  ->  int
// operation: read (link, string)  ->  string
// operation: reduce (poly, ideal)  ->  poly
// operation: reduce (vector, ideal)  ->  vector
// operation: reduce (vector, module)  ->  vector
// operation: reduce (ideal, ideal)  ->  ideal
// operation: reduce (module, module)  ->  module
// operation: reduce (module, ideal)  ->  module
// operation: nres (ideal, int)  ->  resolution
// operation: nres (module, int)  ->  resolution
// operation: status (link, string)  ->  string
// operation: status (list, int)  ->  int
// operation: simplify (poly, int)  ->  poly
// operation: simplify (vector, int)  ->  vector
// operation: simplify (ideal, int)  ->  ideal
// operation: simplify (module, int)  ->  module
// operation: sres (ideal, int)  ->  resolution
// operation: sres (module, int)  ->  resolution
// operation: system (string, def)  ->  any_type
// operation: std (ideal, poly)  ->  ideal
// operation: std (module, vector)  ->  module
// operation: std (ideal, ideal)  ->  ideal
// operation: std (module, module)  ->  module
// operation: std (ideal, intvec)  ->  ideal
// operation: std (module, intvec)  ->  module
// operation: varstr (ring, int)  ->  string
// operation: varstr (qring, int)  ->  string
// operation: waitfirst (list, int)  ->  int
// operation: waitall (list, int)  ->  int
// operation: wedge (matrix, int)  ->  matrix
/*---------------------------------------------*/
// operation: [ (string, int, int)  ->  string
// operation: [ (intmat, int, int)  ->  int
// operation: [ (intmat, int, intvec)  ->  int
// operation: [ (intmat, intvec, int)  ->  int
// operation: [ (intmat, intvec, intvec)  ->  int
// operation: [ (matrix, int, int)  ->  poly
// operation: [ (matrix, int, intvec)  ->  poly
// operation: [ (matrix, intvec, int)  ->  poly
// operation: [ (matrix, intvec, intvec)  ->  poly
// operation: ( (proc, def, def)  ->  any_type
// operation: attrib (identifier, string, def)  ->  nothing
// operation: bareiss (module, int, int)  ->  list
// operation: coeffs (poly, poly, matrix)  ->  matrix
// operation: coeffs (vector, poly, matrix)  ->  matrix
// operation: coeffs (ideal, poly, matrix)  ->  matrix
// operation: coeffs (module, poly, matrix)  ->  matrix
// operation: coeffs (ideal, ideal, poly)  ->  matrix
// operation: coeffs (module, module, poly)  ->  matrix
// operation: eliminate (ideal, poly, intvec)  ->  ideal
// operation: eliminate (module, poly, intvec)  ->  module
// operation: find (string, string, int)  ->  int
// operation: frwalk (ring, def, int)  ->  ideal
// operation: hilb (ideal, int, intvec)  ->  intvec
// operation: hilb (module, int, intvec)  ->  intvec
// operation: homog (poly, poly, intvec)  ->  poly
// operation: homog (vector, poly, intvec)  ->  vector
// operation: homog (ideal, poly, intvec)  ->  ideal
// operation: homog (module, poly, intvec)  ->  module
// operation: ideal (def, def, def)  ->  ideal
// operation: insert (list, def, int)  ->  list
// operation: intmat (intmat, int, int)  ->  intmat
// operation: intvec (def, def, def)  ->  intvec
// operation: jet (poly, int, intvec)  ->  poly
// operation: jet (ideal, int, intvec)  ->  ideal
// operation: jet (vector, int, intvec)  ->  vector
// operation: jet (module, int, intvec)  ->  module
// operation: jet (poly, poly, int)  ->  poly
// operation: jet (vector, poly, int)  ->  vector
// operation: jet (ideal, matrix, int)  ->  ideal
// operation: jet (module, matrix, int)  ->  module
// DUMMY // operation: jet (poly, int, int)  ->  poly
// operation: koszul (int, int, ideal)  ->  matrix
// operation: lift (ideal, ideal, matrix)  ->  matrix
// operation: lift (module, module, matrix)  ->  matrix
// operation: liftstd (ideal, matrix, module)  ->  ideal
// operation: liftstd (module, matrix, module)  ->  module
// operation: list (def, def, def)  ->  list
// operation: matrix (ideal, int, int)  ->  matrix
// operation: matrix (module, int, int)  ->  matrix
// operation: matrix (matrix, int, int)  ->  matrix
// operation: module (def, def, def)  ->  module
// operation: newstruct (string, string, string)  ->  nothing
// operation: preimage (ring, any_type, any_type)  ->  ideal
// operation: preimage (qring, any_type, any_type)  ->  ideal
// operation: random (int, int, int)  ->  intmat
// operation: reduce (poly, ideal, int)  ->  poly
// operation: reduce (vector, ideal, int)  ->  vector
// operation: reduce (vector, module, int)  ->  vector
// operation: reduce (ideal, ideal, int)  ->  ideal
// operation: reduce (module, module, int)  ->  module
// operation: reduce (module, ideal, int)  ->  module
// operation: reduce (poly, poly, ideal)  ->  poly
// operation: reduce (vector, poly, module)  ->  vector
// operation: reduce (ideal, ideal, matrix)  ->  ideal
// operation: reduce (module, module, matrix)  ->  module
// operation: resultant (poly, poly, poly)  ->  poly
// operation: ring (def, def, def)  ->  ring
// operation: status (link, string, string)  ->  int
// operation: std (ideal, intvec, intvec)  ->  ideal
// operation: std (module, intvec, intvec)  ->  module
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (vector, poly, poly)  ->  vector
// operation: subst (ideal, poly, poly)  ->  ideal
// operation: subst (module, poly, poly)  ->  module
// operation: subst (matrix, poly, poly)  ->  matrix
// operation: subst (matrix, poly, int)  ->  matrix
// operation: subst (matrix, poly, number)  ->  matrix
// operation: system (string, def, def)  ->  nothing
// operation: laguerre (poly, int, int)  ->  list
// operation: vandermonde (ideal, ideal, int)  ->  poly
/*---------------------------------------------*/
// operation: ( (...)  ->  any_type ( number of arguments >0 )
// operation: breakpoint (...)  ->  nothing ( 0 arguments )
// operation: breakpoint (...)  ->  nothing ( number of arguments >0 )
// operation: coef (...)  ->  matrix ( 2 arguments )
// operation: coef (...)  ->  nothing ( 4 arguments )
// operation: division (...)  ->  any_type ( 2 arguments )
// operation: division (...)  ->  any_type ( 3 arguments )
// operation: division (...)  ->  any_type ( 4 arguments )
// operation: dbprint (...)  ->  nothing ( number of arguments >0 )
// operation: ideal (...)  ->  ideal ( 1 arguments )
// operation: ideal (...)  ->  ideal ( any number of arguments )
// operation: intersect (...)  ->  ideal ( 2 arguments )
// operation: intersect (...)  ->  ideal ( number of arguments >0 )
// operation: intvec (...)  ->  intvec ( 1 arguments )
// operation: intvec (...)  ->  intvec ( number of arguments >0 )
// operation: jet (...)  ->  poly ( 2 arguments )
// operation: jet (...)  ->  poly ( 3 arguments )
// operation: jet (...)  ->  poly ( 4 arguments )
// operation: LIB (...)  ->  nothing ( 1 arguments )
// operation: list (...)  ->  list ( any number of arguments )
// operation: luinverse (...)  ->  list ( number of arguments >0 )
// operation: lusolve (...)  ->  list ( number of arguments >0 )
// operation: minor (...)  ->  nothing ( 1 arguments )
// operation: minor (...)  ->  ideal ( number of arguments >0 )
// operation: module (...)  ->  module ( 1 arguments )
// operation: module (...)  ->  module ( any number of arguments )
// operation: names (...)  ->  list ( 1 arguments )
// operation: names (...)  ->  list ( 0 arguments )
// operation: option (...)  ->  string ( any number of arguments )
// operation: reduce (...)  ->  ideal ( 2 arguments )
// operation: reduce (...)  ->  ideal ( 3 arguments )
// operation: reduce (...)  ->  ideal ( 4 arguments )
// operation: reduce (...)  ->  ideal ( 5 arguments )
// operation: reservedName (...)  ->  int ( 1 arguments )
// operation: reservedName (...)  ->  nothing ( 0 arguments )
// operation: string (...)  ->  string ( any number of arguments )
// operation: subst (...)  ->  nothing ( 3 arguments )
// operation: subst (...)  ->  nothing ( number of arguments >0 )
// operation: system (...)  ->  nothing ( number of arguments >0 )
// operation: test (...)  ->  nothing ( number of arguments >0 )
// operation: write (...)  ->  nothing ( number of arguments >0 )
// operation: status (...)  ->  string ( 2 arguments )
// operation: status (...)  ->  int ( 3 arguments )
// operation: status (...)  ->  int ( 4 arguments )
// operation: simplex (...)  ->  list ( 6 arguments )
// operation: uressolve (...)  ->  list ( 4 arguments )
// operation: std (...)  ->  ideal ( 1 arguments )
// operation: std (...)  ->  ideal ( 2 arguments )
// operation: std (...)  ->  ideal ( 3 arguments )
// operation: std (...)  ->  ideal ( 4 arguments )
// operation: qrds (...)  ->  list ( 4 arguments )
// operation: factmodd (...)  ->  list ( number of arguments >0 )
/*---------------------------------------------*/
// assign: ideal =  ideal
// assign: ideal =  matrix
// assign: resolution =  resolution
// assign: int =  int
// assign: int =  intmat
// assign: matrix =  matrix
// assign: map =  ideal
// assign: map =  map
// assign: module =  module
// assign: module =  poly
// assign: poly =  poly
// assign: poly =  matrix
// assign: qring =  ideal
// assign: ring =  ring
// assign: qring =  qring
// assign: string =  string
// assign: proc =  string
// assign: proc =  proc
// assign: vector =  vector
// assign: intvec =  intvec
// assign: intmat =  intmat
// assign: number =  number
// assign: bigint =  bigint
// assign: list =  resolution
// assign: list =  list
// assign: link =  string
// assign: link =  link
// assign: package =  package
/*---------------------------------------------*/
// convert intvec -> intmat
// convert poly -> ideal
// convert bigint -> ideal
// convert int -> ideal
// convert intmat -> matrix
// convert ideal -> matrix
// convert module -> matrix
// convert number -> matrix
// convert poly -> matrix
// convert vector -> matrix
// convert bigint -> matrix
// convert int -> matrix
// convert intvec -> matrix
// convert ideal -> module
// convert matrix -> module
// convert vector -> module
// convert bigint -> number
// convert int -> number
// convert number -> poly
// convert bigint -> poly
// convert int -> poly
// convert list -> resolution
// convert poly -> vector
// convert bigint -> vector
// convert int -> vector
// convert int -> bigint
// convert int -> intvec
// convert string -> link
// convert resolution -> list
/*---------------------------------------------*/
// token 61 : =
// token 62 : >
// token 60 : <
// token 43 : +
// token 42 : *
// token 47 : /
// token 91 : [
// token 46 : .
// token 94 : ^
// token 44 : ,
// token 37 : %
// token 40 : (
// token 59 : ;
// token 258 : ..
// token 259 : ==
// token 260 : >=
// token 261 : <=
// token 262 : --
// token 263 : not
// token 264 : <>
// token 265 : ++
// token 266 : ::
// token 268 : intmat
// token 269 : proc
// token 270 : ring
// token 272 : ideal
// token 273 : map
// token 274 : matrix
// token 275 : module
// token 276 : number
// token 277 : poly
// token 278 : resolution
// token 279 : vector
// token 280 : betti
// token 281 : coeffs
// token 282 : coef
// token 283 : contract
// token 284 : degree
// token 285 : deg
// token 286 : diff
// token 287 : dim
// token 288 : division
// token 289 : eliminate
// token 290 : gen
// token 291 : farey
// token 292 : fetch
// token 293 : freemodule
// token 294 : keepring
// token 295 : hilb
// token 296 : homog
// token 297 : imap
// token 298 : indepSet
// token 299 : interred
// token 300 : intersect
// token 301 : jacob
// token 302 : jet
// token 303 : kbase
// token 304 : koszul
// token 305 : leadcoef
// token 306 : leadexp
// token 307 : lead
// token 308 : leadmonom
// token 309 : liftstd
// token 310 : lift
// token 311 : maxideal
// token 312 : minbase
// token 313 : minor
// token 314 : minres
// token 315 : modulo
// token 316 : monomial
// token 317 : mres
// token 318 : mult
// token 319 : ord
// token 320 : par
// token 321 : pardeg
// token 322 : preimage
// token 323 : quotient
// token 324 : qhweight
// token 325 : reduce
// token 326 : regularity
// token 327 : nres
// token 328 : simplify
// token 329 : sortvec
// token 330 : sres
// token 331 : std
// token 332 : subst
// token 333 : syz
// token 334 : var
// token 335 : vdim
// token 336 : wedge
// token 337 : weight
// token 339 : degBound
// token 340 : multBound
// token 341 : noether
// token 342 : minpoly
// token 343 : nothing
// token 355 : example
// token 356 : export
// token 358 : kill
// token 359 : LIB
// token 360 : listvar
// token 361 : setring
// token 362 : type
// token 369 : break
// token 370 : continue
// token 371 : else
// token 372 : eval
// token 373 : quote
// token 375 : forif
// token 378 : return
// token 379 : parameter
// token 383 : command
// token 384 : any_type
// token 385 : identifier
// token 396 : alias
// token 397 : attrib
// token 398 : bareiss
// token 399 : bigint
// token 400 : bracket
// token 401 : breakpoint
// token 402 : char
// token 403 : charstr
// token 404 : char_series
// token 405 : chinrem
// token 406 : close
// token 407 : ncols
// token 408 : cleardenom
// token 409 : size
// token 410 : dbprint
// token 411 : def
// token 412 : defined
// token 413 : delete
// token 414 : det
// token 415 : dump
// token 416 : RETURN
// token 417 : envelope
// token 418 : ERROR
// token 419 : execute
// token 420 : exportto
// token 421 : extgcd
// token 422 : factorize
// token 423 : find
// token 424 : facstd
// token 425 : factmodd
// token 426 : frwalk
// token 427 : fglm
// token 428 : fglmquot
// token 429 : finduni
// token 430 : gcd
// token 431 : getdump
// token 432 : highcorner
// token 433 : hres
// token 434 : impart
// token 435 : importfrom
// token 436 : insert
// token 437 : int
// token 438 : div
// token 439 : interpolation
// token 440 : mod
// token 441 : intvec
// token 442 : rvar
// token 443 : janet
// token 444 : kernel
// token 445 : killattrib
// token 446 : kres
// token 447 : laguerre
// token 448 : link
// token 449 : list
// token 450 : load
// token 451 : lres
// token 452 : ludecomp
// token 453 : luinverse
// token 454 : lusolve
// token 455 : memory
// token 456 : monitor
// token 457 : mpresmat
// token 458 : mstd
// token 459 : nameof
// token 460 : names
// token 461 : newstruct
// token 463 : nc_algebra
// token 464 : convhull
// token 465 : npars
// token 466 : nvars
// token 467 : open
// token 468 : oppose
// token 469 : opposite
// token 470 : option
// token 471 : ordstr
// token 472 : package
// token 473 : parstr
// token 474 : primefactors
// token 476 : prime
// token 477 : print
// token 478 : prune
// token 479 : qring
// token 480 : qrds
// token 481 : random
// token 482 : rank
// token 483 : read
// token 484 : repart
// token 485 : reservedName
// token 486 : resultant
// token 487 : ringlist
// token 488 : nrows
// token 489 : simplex
// token 490 : slimgb
// token 491 : sqrfree
// token 492 : status
// token 493 : string
// token 494 : system
// token 495 : test
// token 496 : transpose
// token 497 : trace
// token 498 : twostd
// token 499 : typeof
// token 500 : univariate
// token 502 : uressolve
// token 503 : vandermonde
// token 504 : variables
// token 505 : varstr
// token 506 : waitfirst
// token 507 : waitall
// token 508 : write
// token 509 : echo
// token 510 : pagewidth
// token 511 : timer
// token 512 : rtimer
// token 513 : TRACE
// token 514 : voice
// token 515 : short
// token 516 : printlevel
/*--max. token: 517, gr: 381 --*/
/*---------------------------------------------*/
struct sValCmdTab dArithTab1[]=
{
 { 40,10 },
 { 45,2 },
 { 262,1 },
 { 265,0 },
 { 268,90 },
 { 269,160 },
 { 270,174 },
 { 272,76 },
 { 273,118 },
 { 274,119 },
 { 275,126 },
 { 276,137 },
 { 277,154 },
 { 278,170 },
 { 279,210 },
 { 280,13 },
 { 284,51 },
 { 285,48 },
 { 287,57 },
 { 290,61 },
 { 293,66 },
 { 295,71 },
 { 296,74 },
 { 298,83 },
 { 299,88 },
 { 301,96 },
 { 303,100 },
 { 305,110 },
 { 306,112 },
 { 307,106 },
 { 308,114 },
 { 311,120 },
 { 312,122 },
 { 314,124 },
 { 316,128 },
 { 318,129 },
 { 319,145 },
 { 320,149 },
 { 321,150 },
 { 322,156 },
 { 324,162 },
 { 326,167 },
 { 329,183 },
 { 331,186 },
 { 333,190 },
 { 334,213 },
 { 335,211 },
 { 337,217 },
 { 397,11 },
 { 398,12 },
 { 399,17 },
 { 402,20 },
 { 403,23 },
 { 404,22 },
 { 406,25 },
 { 407,26 },
 { 408,31 },
 { 409,33 },
 { 411,46 },
 { 412,53 },
 { 414,54 },
 { 415,60 },
 { 417,192 },
 { 418,63 },
 { 419,62 },
 { 422,64 },
 { 424,67 },
 { 429,65 },
 { 431,68 },
 { 432,69 },
 { 434,82 },
 { 437,84 },
 { 441,91 },
 { 442,93 },
 { 443,99 },
 { 445,105 },
 { 448,116 },
 { 449,117 },
 { 450,219 },
 { 452,102 },
 { 455,121 },
 { 456,127 },
 { 458,131 },
 { 459,133 },
 { 460,134 },
 { 464,220 },
 { 465,140 },
 { 466,142 },
 { 467,144 },
 { 469,194 },
 { 471,147 },
 { 473,151 },
 { 474,103 },
 { 476,157 },
 { 477,158 },
 { 478,161 },
 { 479,164 },
 { 482,165 },
 { 483,166 },
 { 484,168 },
 { 485,169 },
 { 487,172 },
 { 488,176 },
 { 490,181 },
 { 491,185 },
 { 493,188 },
 { 494,189 },
 { 496,201 },
 { 497,197 },
 { 498,196 },
 { 499,205 },
 { 500,206 },
 { 504,207 },
 { 505,214 },
 { 506,221 },
 { 507,222 },
 { 10000,0 }
};
#define JJTAB1LEN 116
struct sValCmdTab dArithTab2[]=
{
 { 37,79 },
 { 38,126 },
 { 40,171 },
 { 42,36 },
 { 43,1 },
 { 45,23 },
 { 47,67 },
 { 58,176 },
 { 60,102 },
 { 62,118 },
 { 91,156 },
 { 94,89 },
 { 124,127 },
 { 258,155 },
 { 259,128 },
 { 260,110 },
 { 261,94 },
 { 264,142 },
 { 266,0 },
 { 272,239 },
 { 275,269 },
 { 280,178 },
 { 281,187 },
 { 282,186 },
 { 283,191 },
 { 285,192 },
 { 286,196 },
 { 287,202 },
 { 288,204 },
 { 289,206 },
 { 291,215 },
 { 292,219 },
 { 295,230 },
 { 296,232 },
 { 297,240 },
 { 298,243 },
 { 300,246 },
 { 302,249 },
 { 303,254 },
 { 304,259 },
 { 309,264 },
 { 310,262 },
 { 315,270 },
 { 317,275 },
 { 323,294 },
 { 325,300 },
 { 327,306 },
 { 328,310 },
 { 330,314 },
 { 331,317 },
 { 336,327 },
 { 397,177 },
 { 400,182 },
 { 405,183 },
 { 413,195 },
 { 420,210 },
 { 421,211 },
 { 422,213 },
 { 423,224 },
 { 424,214 },
 { 426,225 },
 { 427,221 },
 { 428,223 },
 { 430,226 },
 { 433,238 },
 { 435,242 },
 { 436,244 },
 { 438,75 },
 { 439,245 },
 { 440,84 },
 { 443,248 },
 { 444,256 },
 { 445,258 },
 { 446,261 },
 { 449,266 },
 { 450,267 },
 { 451,268 },
 { 456,272 },
 { 457,273 },
 { 461,274 },
 { 462,281 },
 { 463,285 },
 { 468,289 },
 { 473,291 },
 { 474,277 },
 { 477,293 },
 { 481,297 },
 { 482,298 },
 { 483,299 },
 { 492,308 },
 { 494,316 },
 { 505,323 },
 { 506,325 },
 { 507,326 },
 { 10000,0 }
};
#define JJTAB2LEN 94
/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// identifier table for Singular
//
#ifdef MODULE_GENERATOR
#define omAlloc0(A) malloc(A)
#endif
void iiInitCmdName()
{
  sArithBase.nCmdUsed      = 0;
  sArithBase.nCmdAllocated = 225;
  sArithBase.sCmds = (cmdnames*)omAlloc0(sArithBase.nCmdAllocated*sizeof(cmdnames));

  // name-string                   alias  tokval toktype index
  iiArithAddCmd("$INVALID$",           0,  -1, 0, 0);
  iiArithAddCmd("ERROR",               0, 418, CMD_1, 1);
  iiArithAddCmd("GCD",                 2, 430, CMD_2, 2);
  iiArithAddCmd("IN",                  1, 307, CMD_1, 3);
  iiArithAddCmd("LIB",                 0, 359, SYSVAR, 4);
  iiArithAddCmd("NF",                  1, 325, CMD_M, 5);
  iiArithAddCmd("RETURN",              0, 416, 378, 6);
  iiArithAddCmd("TRACE",               0, 513, SYSVAR, 7);
  iiArithAddCmd("alias",               0, 396, 379, 8);
  iiArithAddCmd("and",                 0,  38, '&', 9);
  iiArithAddCmd("attrib",              0, 397, CMD_123, 10);
  iiArithAddCmd("bareiss",             0, 398, 348, 11);
  iiArithAddCmd("betti",               0, 280, CMD_12, 12);
  iiArithAddCmd("bigint",              0, 399, ROOT_DECL, 13);
  iiArithAddCmd("bracket",             0, 400, CMD_2, 14);
  iiArithAddCmd("break",               0, 369, 369, 15);
  iiArithAddCmd("breakpoint",          0, 401, CMD_M, 16);
  iiArithAddCmd("char",                0, 402, CMD_1, 17);
  iiArithAddCmd("char_series",         0, 404, CMD_1, 18);
  iiArithAddCmd("charstr",             0, 403, CMD_1, 19);
  iiArithAddCmd("chinrem",             0, 405, CMD_2, 20);
  iiArithAddCmd("cleardenom",          0, 408, CMD_1, 21);
  iiArithAddCmd("close",               0, 406, CMD_1, 22);
  iiArithAddCmd("coef",                0, 282, CMD_M, 23);
  iiArithAddCmd("coeffs",              0, 281, CMD_23, 24);
  iiArithAddCmd("continue",            0, 370, 370, 25);
  iiArithAddCmd("contract",            0, 283, CMD_2, 26);
  iiArithAddCmd("convhull",            0, 464, CMD_1, 27);
  iiArithAddCmd("dbprint",             0, 410, CMD_M, 28);
  iiArithAddCmd("def",                 0, 411, ROOT_DECL, 29);
  iiArithAddCmd("defined",             0, 412, CMD_1, 30);
  iiArithAddCmd("deg",                 0, 285, CMD_12, 31);
  iiArithAddCmd("degBound",            0, 339, SYSVAR, 32);
  iiArithAddCmd("degree",              0, 284, CMD_1, 33);
  iiArithAddCmd("delete",              0, 413, CMD_2, 34);
  iiArithAddCmd("det",                 0, 414, CMD_1, 35);
  iiArithAddCmd("diff",                0, 286, CMD_2, 36);
  iiArithAddCmd("dim",                 0, 287, CMD_1, 37);
  iiArithAddCmd("div",                 0, 438, '/', 38);
  iiArithAddCmd("division",            0, 288, CMD_M, 39);
  iiArithAddCmd("dump",                0, 415, CMD_1, 40);
  iiArithAddCmd("echo",                0, 509, SYSVAR, 41);
  iiArithAddCmd("eliminate",           0, 289, CMD_23, 42);
  iiArithAddCmd("else",                0, 371, 371, 43);
  iiArithAddCmd("envelope",            0, 417, CMD_1, 44);
  iiArithAddCmd("eval",                0, 372, 372, 45);
  iiArithAddCmd("example",             0, 355, 355, 46);
  iiArithAddCmd("execute",             0, 419, CMD_1, 47);
  iiArithAddCmd("export",              0, 356, 356, 48);
  iiArithAddCmd("exportto",            0, 420, CMD_2, 49);
  iiArithAddCmd("extgcd",              0, 421, CMD_2, 50);
  iiArithAddCmd("facstd",              0, 424, CMD_12, 51);
  iiArithAddCmd("factmodd",            0, 425, CMD_M, 52);
  iiArithAddCmd("factorize",           0, 422, CMD_12, 53);
  iiArithAddCmd("farey",               0, 291, CMD_2, 54);
  iiArithAddCmd("fetch",               0, 292, CMD_2, 55);
  iiArithAddCmd("fglm",                0, 427, CMD_2, 56);
  iiArithAddCmd("fglmquot",            0, 428, CMD_2, 57);
  iiArithAddCmd("find",                0, 423, CMD_23, 58);
  iiArithAddCmd("finduni",             0, 429, CMD_1, 59);
  iiArithAddCmd("forif",               0, 375, 375, 60);
  iiArithAddCmd("freemodule",          0, 293, CMD_1, 61);
  iiArithAddCmd("frwalk",              0, 426, CMD_23, 62);
  iiArithAddCmd("gcd",                 0, 430, CMD_2, 63);
  iiArithAddCmd("gen",                 0, 290, CMD_1, 64);
  iiArithAddCmd("getdump",             0, 431, CMD_1, 65);
  iiArithAddCmd("highcorner",          0, 432, CMD_1, 66);
  iiArithAddCmd("hilb",                0, 295, CMD_123, 67);
  iiArithAddCmd("homog",               0, 296, CMD_123, 68);
  iiArithAddCmd("hres",                0, 433, CMD_2, 69);
  iiArithAddCmd("ideal",               0, 272, 272, 70);
  iiArithAddCmd("if",                  0, 375, 375, 71);
  iiArithAddCmd("imap",                0, 297, CMD_2, 72);
  iiArithAddCmd("impart",              0, 434, CMD_1, 73);
  iiArithAddCmd("importfrom",          0, 435, CMD_2, 74);
  iiArithAddCmd("indepSet",            0, 298, CMD_12, 75);
  iiArithAddCmd("insert",              0, 436, CMD_23, 76);
  iiArithAddCmd("int",                 0, 437, ROOT_DECL, 77);
  iiArithAddCmd("interpolation",       0, 439, CMD_2, 78);
  iiArithAddCmd("interred",            0, 299, CMD_1, 79);
  iiArithAddCmd("intersect",           0, 300, CMD_M, 80);
  iiArithAddCmd("intmat",              0, 268, 268, 81);
  iiArithAddCmd("intvec",              0, 441, ROOT_DECL_LIST, 82);
  iiArithAddCmd("jacob",               0, 301, CMD_1, 83);
  iiArithAddCmd("janet",               0, 443, CMD_12, 84);
  iiArithAddCmd("jet",                 0, 302, CMD_M, 85);
  iiArithAddCmd("kbase",               0, 303, CMD_12, 86);
  iiArithAddCmd("keepring",            0, 294, 294, 87);
  iiArithAddCmd("kernel",              0, 444, CMD_2, 88);
  iiArithAddCmd("kill",                0, 358, 358, 89);
  iiArithAddCmd("killattrib",          0, 445, CMD_12, 90);
  iiArithAddCmd("koszul",              0, 304, CMD_23, 91);
  iiArithAddCmd("kres",                0, 446, CMD_2, 92);
  iiArithAddCmd("laguerre",            0, 447, CMD_3, 93);
  iiArithAddCmd("lead",                0, 307, CMD_1, 94);
  iiArithAddCmd("leadcoef",            0, 305, CMD_1, 95);
  iiArithAddCmd("leadexp",             0, 306, CMD_1, 96);
  iiArithAddCmd("leadmonom",           0, 308, CMD_1, 97);
  iiArithAddCmd("lift",                0, 310, CMD_23, 98);
  iiArithAddCmd("liftstd",             0, 309, CMD_23, 99);
  iiArithAddCmd("link",                0, 448, ROOT_DECL, 100);
  iiArithAddCmd("list",                0, 449, ROOT_DECL_LIST, 101);
  iiArithAddCmd("listvar",             0, 360, 360, 102);
  iiArithAddCmd("load",                0, 450, CMD_12, 103);
  iiArithAddCmd("lres",                0, 451, CMD_2, 104);
  iiArithAddCmd("ludecomp",            0, 452, CMD_1, 105);
  iiArithAddCmd("luinverse",           0, 453, CMD_M, 106);
  iiArithAddCmd("lusolve",             0, 454, CMD_M, 107);
  iiArithAddCmd("map",                 0, 273, RING_DECL, 108);
  iiArithAddCmd("matrix",              0, 274, 274, 109);
  iiArithAddCmd("maxideal",            0, 311, CMD_1, 110);
  iiArithAddCmd("memory",              0, 455, CMD_1, 111);
  iiArithAddCmd("minbase",             0, 312, CMD_1, 112);
  iiArithAddCmd("minor",               0, 313, CMD_M, 113);
  iiArithAddCmd("minpoly",             0, 342, SYSVAR, 114);
  iiArithAddCmd("minres",              0, 314, CMD_1, 115);
  iiArithAddCmd("mod",                 0, 440, '/', 116);
  iiArithAddCmd("module",              0, 275, 275, 117);
  iiArithAddCmd("modulo",              0, 315, CMD_2, 118);
  iiArithAddCmd("monitor",             0, 456, CMD_12, 119);
  iiArithAddCmd("monomial",            0, 316, CMD_1, 120);
  iiArithAddCmd("mpresmat",            0, 457, CMD_2, 121);
  iiArithAddCmd("mres",                0, 317, CMD_2, 122);
  iiArithAddCmd("mstd",                0, 458, CMD_1, 123);
  iiArithAddCmd("mult",                0, 318, CMD_1, 124);
  iiArithAddCmd("multBound",           0, 340, SYSVAR, 125);
  iiArithAddCmd("multiplicity",        1, 318, CMD_1, 126);
  iiArithAddCmd("nameof",              0, 459, CMD_1, 127);
  iiArithAddCmd("names",               0, 460, CMD_M, 128);
  iiArithAddCmd("nc_algebra",          0, 463, CMD_2, 129);
  iiArithAddCmd("ncalgebra",           2, 462, CMD_2, 130);
  iiArithAddCmd("ncols",               0, 407, CMD_1, 131);
  iiArithAddCmd("newstruct",           0, 461, CMD_23, 132);
  iiArithAddCmd("noether",             0, 341, SYSVAR, 133);
  iiArithAddCmd("not",                 0, 263, 263, 134);
  iiArithAddCmd("npars",               0, 465, CMD_1, 135);
  iiArithAddCmd("nres",                0, 327, CMD_2, 136);
  iiArithAddCmd("nrows",               0, 488, CMD_1, 137);
  iiArithAddCmd("number",              0, 276, RING_DECL, 138);
  iiArithAddCmd("nvars",               0, 466, CMD_1, 139);
  iiArithAddCmd("open",                0, 467, CMD_1, 140);
  iiArithAddCmd("oppose",              0, 468, CMD_2, 141);
  iiArithAddCmd("opposite",            0, 469, CMD_1, 142);
  iiArithAddCmd("option",              0, 470, CMD_M, 143);
  iiArithAddCmd("or",                  0, 124, '&', 144);
  iiArithAddCmd("ord",                 0, 319, CMD_1, 145);
  iiArithAddCmd("ordstr",              0, 471, CMD_1, 146);
  iiArithAddCmd("package",             0, 472, ROOT_DECL, 147);
  iiArithAddCmd("pagewidth",           0, 510, SYSVAR, 148);
  iiArithAddCmd("par",                 0, 320, CMD_1, 149);
  iiArithAddCmd("parameter",           0, 379, 379, 150);
  iiArithAddCmd("pardeg",              0, 321, CMD_1, 151);
  iiArithAddCmd("parstr",              0, 473, CMD_12, 152);
  iiArithAddCmd("poly",                0, 277, RING_DECL, 153);
  iiArithAddCmd("preimage",            0, 322, 348, 154);
  iiArithAddCmd("prime",               0, 476, CMD_1, 155);
  iiArithAddCmd("primefactors",        0, 474, CMD_12, 156);
  iiArithAddCmd("print",               0, 477, CMD_12, 157);
  iiArithAddCmd("printlevel",          0, 516, SYSVAR, 158);
  iiArithAddCmd("proc",                0, 269, 269, 159);
  iiArithAddCmd("prune",               0, 478, CMD_1, 160);
  iiArithAddCmd("qhweight",            0, 324, CMD_1, 161);
  iiArithAddCmd("qrds",                0, 480, CMD_M, 162);
  iiArithAddCmd("qring",               0, 479, ROOT_DECL, 163);
  iiArithAddCmd("quote",               0, 373, 373, 164);
  iiArithAddCmd("quotient",            0, 323, CMD_2, 165);
  iiArithAddCmd("random",              0, 481, CMD_23, 166);
  iiArithAddCmd("rank",                0, 482, CMD_12, 167);
  iiArithAddCmd("read",                0, 483, CMD_12, 168);
  iiArithAddCmd("reduce",              0, 325, CMD_M, 169);
  iiArithAddCmd("regularity",          0, 326, CMD_1, 170);
  iiArithAddCmd("repart",              0, 484, CMD_1, 171);
  iiArithAddCmd("reservedName",        0, 485, CMD_M, 172);
  iiArithAddCmd("resolution",          0, 278, RING_DECL, 173);
  iiArithAddCmd("resultant",           0, 486, CMD_3, 174);
  iiArithAddCmd("return",              0, 378, 378, 175);
  iiArithAddCmd("ring",                0, 270, 270, 176);
  iiArithAddCmd("ringlist",            0, 487, CMD_1, 177);
  iiArithAddCmd("rtimer",              0, 512, SYSVAR, 178);
  iiArithAddCmd("rvar",                0, 442, CMD_1, 179);
  iiArithAddCmd("setring",             0, 361, 361, 180);
  iiArithAddCmd("short",               0, 515, SYSVAR, 181);
  iiArithAddCmd("simplex",             0, 489, CMD_M, 182);
  iiArithAddCmd("simplify",            0, 328, CMD_2, 183);
  iiArithAddCmd("size",                0, 409, CMD_1, 184);
  iiArithAddCmd("slimgb",              0, 490, CMD_1, 185);
  iiArithAddCmd("sortvec",             0, 329, CMD_1, 186);
  iiArithAddCmd("sqrfree",             0, 491, CMD_1, 187);
  iiArithAddCmd("sres",                0, 330, CMD_2, 188);
  iiArithAddCmd("status",              0, 492, CMD_M, 189);
  iiArithAddCmd("std",                 0, 331, CMD_M, 190);
  iiArithAddCmd("string",              0, 493, ROOT_DECL_LIST, 191);
  iiArithAddCmd("subst",               0, 332, CMD_M, 192);
  iiArithAddCmd("system",              0, 494, CMD_M, 193);
  iiArithAddCmd("syz",                 0, 333, CMD_1, 194);
  iiArithAddCmd("test",                0, 495, CMD_M, 195);
  iiArithAddCmd("timer",               0, 511, SYSVAR, 196);
  iiArithAddCmd("trace",               0, 497, CMD_1, 197);
  iiArithAddCmd("transpose",           0, 496, CMD_1, 198);
  iiArithAddCmd("twostd",              0, 498, CMD_1, 199);
  iiArithAddCmd("type",                0, 362, 362, 200);
  iiArithAddCmd("typeof",              0, 499, CMD_1, 201);
  iiArithAddCmd("univariate",          0, 500, CMD_1, 202);
  iiArithAddCmd("uressolve",           0, 502, CMD_M, 203);
  iiArithAddCmd("vandermonde",         0, 503, CMD_3, 204);
  iiArithAddCmd("var",                 0, 334, CMD_1, 205);
  iiArithAddCmd("variables",           0, 504, CMD_1, 206);
  iiArithAddCmd("varstr",              0, 505, CMD_12, 207);
  iiArithAddCmd("vdim",                0, 335, CMD_1, 208);
  iiArithAddCmd("vector",              0, 279, RING_DECL, 209);
  iiArithAddCmd("verbose",             2, 470, CMD_M, 210);
  iiArithAddCmd("voice",               0, 514, SYSVAR, 211);
  iiArithAddCmd("waitall",             0, 507, CMD_12, 212);
  iiArithAddCmd("waitfirst",           0, 506, CMD_12, 213);
  iiArithAddCmd("wedge",               0, 336, CMD_2, 214);
  iiArithAddCmd("weight",              0, 337, CMD_1, 215);
  iiArithAddCmd("whileif",             0, 375, 375, 216);
  iiArithAddCmd("write",               0, 508, CMD_M, 217);
  iiArithAddCmd("exit",                0,  -1, 0, 218);
  iiArithAddCmd("for",                 0,  -1, 0, 219);
  iiArithAddCmd("help",                0,  -1, 0, 220);
  iiArithAddCmd("newline",             0,  -1, 0, 221);
  iiArithAddCmd("pause",               2,  -1, 0, 222);
  iiArithAddCmd("quit",                0,  -1, 0, 223);
  iiArithAddCmd("while",               0,  -1, 0, 224);
/* end of list marker */
  sArithBase.nLastIdentifier = 217;
}
#define LAST_IDENTIFIER 217
